@@ -26,7 +26,7 @@ import os
 import sys
 from configparser import ConfigParser
 from pathlib import Path, PurePosixPath
-from typing import Dict, Iterable, Iterator, List, Tuple, Union
+from typing import Dict, Iterable, Iterator, Tuple, Union
 
 import click
 
@@ -44,7 +44,7 @@ def _config_filepath() -> str:
         The path of the config file.
 
     """
-    home = "HOMEPATH" if os.name == "nt" else "HOME"
+    home = "USERPROFILE" if os.name == "nt" else "HOME"
     return os.path.join(os.environ[home], ".gasconfig")
 
 
@@ -100,9 +100,9 @@ def _gas(access_key: str, url: str, profile_name: str) -> GAS:
 
 
 @click.group()
-@click.version_option(version=__version__, message="%(version)s")
+@click.version_option(__version__)
 @click.option("-k", "--key", "access_key", type=str, default="", help="The accessKey of gas.")
-@click.option("-u", "--url", type=str, default="", help="The login url.")
+@click.option("-u", "--url", type=str, default="", help="The login url.", hidden=True)
 @click.option(
     "-p",
     "--profile",
@@ -114,7 +114,6 @@ def _gas(access_key: str, url: str, profile_name: str) -> GAS:
 @click.option("-d", "--debug", is_flag=True, help="Debug mode.")
 @click.pass_context
 def cli(ctx: click.Context, access_key: str, url: str, profile_name: str, debug: bool) -> None:
-    # noqa: D415, D301
     """You can use 'gas' + COMMAND to operate on your dataset.\f
 
     Arguments:
@@ -124,7 +123,7 @@ def cli(ctx: click.Context, access_key: str, url: str, profile_name: str, debug:
         profile_name: The environment to login.
         debug: Debug mode flag.
 
-    """
+    """  # noqa: D301,D415
     ctx.obj = {
         "access_key": access_key,
         "url": url,
@@ -139,14 +138,13 @@ def cli(ctx: click.Context, access_key: str, url: str, profile_name: str, debug:
 @click.argument("name", type=str)
 @click.pass_obj
 def create(obj: Dict[str, str], name: str) -> None:
-    # noqa: D415, D301
     """Create a dataset.\f
 
     Arguments:
         obj: A dict including config information.
         name: The name of the dataset to be created, like "tb:KITTI".
 
-    """
+    """  # noqa: D301,D415
     info = TBRN(tbrn=name)
     if info.type != TBRNType.DATASET:
         click.echo(f'"{name}" is not a dataset', err=True)
@@ -160,7 +158,6 @@ def create(obj: Dict[str, str], name: str) -> None:
 # @click.argument("tag", type=str, required=False)
 # @click.pass_obj
 # def commit(obj: Dict[str, str], name: str, message: str, tag: str) -> None:
-#     # noqa: D415, D301
 #     """Commit a dataset.\f
 
 #     Arguments:
@@ -183,7 +180,6 @@ def create(obj: Dict[str, str], name: str) -> None:
 @click.option("-y", "--yes", is_flag=True, help="Confirm to delete the dataset completely.")
 @click.pass_obj
 def delete(obj: Dict[str, str], name: str, yes: bool) -> None:
-    # noqa: D415, D301
     """Delete a dataset.\f
 
     Arguments:
@@ -191,7 +187,7 @@ def delete(obj: Dict[str, str], name: str, yes: bool) -> None:
         name: The name of the dataset to be deleted, like "tb:KITTI".
         yes: Confirm to delete the dataset completely.
 
-    """
+    """  # noqa: D301,D415
     info = TBRN(tbrn=name)
     if info.type != TBRNType.DATASET:
         click.echo(f'"{name}" is not a dataset', err=True)
@@ -205,73 +201,6 @@ def delete(obj: Dict[str, str], name: str, yes: bool) -> None:
     _gas(**obj).delete_dataset(info.dataset_name)
 
 
-@cli.command()
-@click.argument("local_paths", type=str, nargs=-1)
-@click.argument("tbrn", type=str, nargs=1)
-@click.option(
-    "-r", "--recursive", "is_recursive", is_flag=True, help="Copy directories recursively."
-)
-@click.option("-j", "--jobs", type=int, default=1, help="The number of threads.")
-@click.option(
-    "-s",
-    "--skip_uploaded_files",
-    "skip_uploaded_files",
-    is_flag=True,
-    help="Whether to skip the uploaded files.",
-)
-@click.pass_obj
-def cp(  # pylint: disable=invalid-name, too-many-arguments
-    obj: Dict[str, str],
-    local_paths: Iterable[str],
-    tbrn: str,
-    is_recursive: bool,
-    jobs: int,
-    skip_uploaded_files: bool,
-) -> None:
-    # noqa: D415, D301
-    """Copy local data to a remote path.\f
-
-    Arguments:
-        obj: A dict contains config information.
-        local_paths: An iterable of local paths contains data to be uploaded.
-        tbrn: The path to save the uploaded data, like "tb:KITTI:seg1".
-        is_recursive: Whether copy directories recursively.
-        jobs: Number of threads to upload data.
-        skip_uploaded_files: Whether skip the uploaded files.
-
-    """
-    info = TBRN(tbrn=tbrn)
-
-    if info.type == TBRNType.DATASET:
-        click.echo("Error: SEGMENT is required", err=True)
-        sys.exit(1)
-
-    if info.type in [TBRNType.SEGMENT, TBRNType.NORMAL_FILE]:
-        target_remote_path = info.remote_path if info.type == TBRNType.NORMAL_FILE else ""
-
-        dataset = _gas(**obj).get_dataset(info.dataset_name)
-        local_abspaths: List[str] = [os.path.abspath(local_path) for local_path in local_paths]
-        if (
-            len(local_abspaths) == 1
-            and not os.path.isdir(local_abspaths[0])
-            and target_remote_path
-            and not target_remote_path.endswith("/")
-        ):
-            dataset.get_or_create_segment(info.segment_name).upload_data(
-                local_abspaths[0], target_remote_path
-            )
-            return
-
-        segment = _get_segment_object(
-            info.segment_name, local_abspaths, target_remote_path, is_recursive
-        )
-        dataset.upload_segment_object(segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files)
-        return
-
-    click.echo(f'"{tbrn}" is an invalid path', err=True)
-    sys.exit(1)
-
-
 def _get_segment_object(
     segment_name: str,
     local_abspaths: Iterable[str],
@@ -340,9 +269,9 @@ def _echo_segment(
 
     """
     if isinstance(segment, SegmentClient):
-        _echo_data(dataset_name, segment_name, segment.list_data())
+        _echo_data(dataset_name, segment_name, segment.list_data_paths())
     else:
-        frames = segment.list_frame_objects()
+        frames = segment.list_frames()
         if not list_all_files:
             for index, _ in enumerate(frames):
                 click.echo(TBRN(dataset_name, segment_name, index).get_tbrn())
@@ -374,7 +303,7 @@ def _echo_data(dataset_name: str, segment_name: str, data_iter: Iterable[str]) -
 
 
 def _ls_dataset(gas: GAS, info: TBRN, list_all_files: bool) -> None:
-    dataset = gas._get_dataset(info.dataset_name)  # pylint: disable=protected-access
+    dataset = gas._get_dataset_with_any_type(info.dataset_name)  # pylint: disable=protected-access
     segment_names = dataset.list_segment_names()
     if not list_all_files:
         for segment_name in segment_names:
@@ -387,20 +316,18 @@ def _ls_dataset(gas: GAS, info: TBRN, list_all_files: bool) -> None:
 
 
 def _ls_segment(gas: GAS, info: TBRN, list_all_files: bool) -> None:
-    dataset = gas._get_dataset(info.dataset_name)  # pylint: disable=protected-access
+    dataset = gas._get_dataset_with_any_type(info.dataset_name)  # pylint: disable=protected-access
     _echo_segment(
         info.dataset_name, info.segment_name, dataset.get_segment(info.segment_name), list_all_files
     )
 
 
 def _ls_frame(gas: GAS, info: TBRN, list_all_files: bool) -> None:
-    dataset = gas.get_dataset(info.dataset_name, is_fusion=True)
-    fusion_segment = dataset.get_segment(info.segment_name)
+    dataset_client = gas.get_dataset(info.dataset_name, is_fusion=True)
+    segment_client = dataset_client.get_segment(info.segment_name)
 
     try:
-        frame = next(
-            fusion_segment.list_frame_objects(start=info.frame_index, stop=info.frame_index + 1)
-        )
+        frame = next(segment_client.list_frames(start=info.frame_index, stop=info.frame_index + 1))
     except StopIteration:
         click.echo(f'No such frame: "{info.frame_index}"!', err=True)
         sys.exit(1)
@@ -426,12 +353,10 @@ def _ls_sensor(
     info: TBRN,
     list_all_files: bool,  # pylint: disable=unused-argument
 ) -> None:
-    dataset = gas.get_dataset(info.dataset_name, is_fusion=True)
-    fusion_segment = dataset.get_segment(info.segment_name)
+    dataset_client = gas.get_dataset(info.dataset_name, is_fusion=True)
+    segment_client = dataset_client.get_segment(info.segment_name)
     try:
-        frame = next(
-            fusion_segment.list_frame_objects(start=info.frame_index, stop=info.frame_index + 1)
-        )
+        frame = next(segment_client.list_frames(start=info.frame_index, stop=info.frame_index + 1))
     except StopIteration:
         click.echo(f'No such frame: "{info.frame_index}"!', err=True)
         sys.exit(1)
@@ -453,12 +378,10 @@ def _ls_fusion_file(
     info: TBRN,
     list_all_files: bool,  # pylint: disable=unused-argument
 ) -> None:
-    dataset = gas.get_dataset(info.dataset_name, is_fusion=True)
-    fusion_segment = dataset.get_segment(info.segment_name)
+    dataset_client = gas.get_dataset(info.dataset_name, is_fusion=True)
+    segment_client = dataset_client.get_segment(info.segment_name)
     try:
-        frame = next(
-            fusion_segment.list_frame_objects(start=info.frame_index, stop=info.frame_index + 1)
-        )
+        frame = next(segment_client.list_frames(start=info.frame_index, stop=info.frame_index + 1))
     except StopIteration:
         click.echo(f'No such frame: "{info.frame_index}"!', err=True)
         sys.exit(1)
@@ -473,12 +396,12 @@ def _ls_fusion_file(
 def _ls_normal_file(  # pylint: disable=unused-argument
     gas: GAS, info: TBRN, list_all_files: bool
 ) -> None:
-    dataset = gas.get_dataset(info.dataset_name)
-    segment = dataset.get_segment(info.segment_name)
+    dataset_client = gas.get_dataset(info.dataset_name)
+    segment_client = dataset_client.get_segment(info.segment_name)
     _echo_data(
         info.dataset_name,
         info.segment_name,
-        _filter_data(segment.list_data(), info.remote_path),
+        _filter_data(segment_client.list_data_paths(), info.remote_path),
     )
 
 
@@ -501,7 +424,6 @@ _LS_FUNCS = {
 def ls(  # pylint: disable=invalid-name
     obj: Dict[str, str], tbrn: str, list_all_files: bool
 ) -> None:
-    # noqa: D415, D301
     """List data under the path. If path is empty, list the names of all datasets.\f
 
     Arguments:
@@ -509,7 +431,7 @@ def ls(  # pylint: disable=invalid-name
         tbrn: Path to be listed, like "tb:KITTI:seg1". If empty, list names of all datasets.
         list_all_files: If true, list all files under the segment.
 
-    """
+    """  # noqa: D301,D415
     gas = _gas(**obj)
 
     if not tbrn:
@@ -604,7 +526,6 @@ def _filter_data(
 @click.argument("url", type=str, default="")
 @click.pass_obj
 def config(obj: Dict[str, str], access_key: str, url: str) -> None:
-    # noqa: D415, D301
     """Configure the accessKey (and URL) of gas.\f
 
     Arguments:
@@ -612,7 +533,7 @@ def config(obj: Dict[str, str], access_key: str, url: str) -> None:
         access_key: The accessKey of gas to write into config file.
         url: The URL of gas to write into config file.
 
-    """
+    """  # noqa: D301,D415
     config_file = _config_filepath()
     config_parser = ConfigParser()
     config_parser.read(config_file)
