@@ -6,17 +6,25 @@
 """Transform3D.
 
 :class:`Transform3D` contains the rotation and translation of a 3D transform.
+:attr:`Transform3D.translation` is stored as :class:`.Vector3D`,
+and :attr:`Transform3D.rotation` is stored as `numpy quaternion`_.
+
+.. _numpy quaternion: https://github.com/moble/quaternion/
 
 """
 
-from typing import Dict, Iterable, Optional, Sequence, Type, TypeVar, Union, overload
+import warnings
+from typing import Dict, Iterable, Sequence, Type, TypeVar, Union, overload
 
 import numpy as np
 
 from ..utility import ReprMixin, ReprType, common_loads
-from .quaternion import Quaternion
 from .vector import Vector3D
 
+with warnings.catch_warnings():
+    warnings.simplefilter("ignore")
+    from quaternion import as_rotation_matrix, from_rotation_matrix, quaternion, rotate_vectors
+
 _T = TypeVar("_T", bound="Transform3D")
 
 
@@ -28,10 +36,7 @@ class Transform3D(ReprMixin):
     Arguments:
         transform: A :class:`Transform3D` or a 4x4 or 3x4 transform matrix.
         translation: Translation in a sequence of [x, y, z].
-        rotation: Rotation in a sequence of [w, x, y, z] or a
-            3x3 rotation matrix or :class:`~tensorbay.geometry.quaternion.Quaternion`.
-        **kwargs: Other parameters to initialize rotation of the transform.
-            See :class:`~tensorbay.geometry.quaternion.Quaternion` documents for details.
+        rotation: Rotation in a sequence of [w, x, y, z] or numpy quaternion.
 
     Raises:
         ValueError: If the shape of the input matrix is not correct.
@@ -43,14 +48,14 @@ class Transform3D(ReprMixin):
 
     MatrixType = Union[None, Sequence[Sequence[float]], np.ndarray]
     TransformType = Union[None, "Transform3D", Sequence[Sequence[float]], np.ndarray]
+    RotationType = Union[Iterable[float], quaternion]
 
     def __init__(
         self,
         transform: TransformType = None,
         *,
-        translation: Optional[Iterable[float]] = None,
-        rotation: Quaternion.ArgsType = None,
-        **kwargs: Quaternion.KwargsType,
+        translation: Iterable[float] = (0, 0, 0),
+        rotation: RotationType = (1, 0, 0, 0),
     ) -> None:
         if transform is not None:
             if isinstance(transform, Transform3D):
@@ -64,36 +69,37 @@ class Transform3D(ReprMixin):
                 raise ValueError("The shape of input transform matrix must be 3x4 or 4x4.")
 
             self._translation = Vector3D(transform[0, 3], transform[1, 3], transform[2, 3])
-            self._rotation = Quaternion(transform)
+            self._rotation = from_rotation_matrix(transform)
             return
 
-        self._translation = Vector3D(translation)
-        self._rotation = Quaternion(rotation, **kwargs)
+        self._translation = Vector3D(*translation)
+        if isinstance(rotation, quaternion):
+            self._rotation = quaternion(rotation)
+        else:
+            self._rotation = quaternion(*rotation)
 
     def __eq__(self, other: object) -> bool:
-        if isinstance(other, self.__class__):
-            return self._translation.__eq__(other.translation) and self._rotation == other.rotation
+        if not isinstance(other, self.__class__):
+            return False
 
-        return False
+        return self._translation.__eq__(other.translation) and self._rotation == other.rotation
 
     @overload
     def __mul__(self: _T, other: _T) -> _T:
         ...
 
-    @overload
-    def __mul__(self: _T, other: Quaternion) -> _T:
-        ...
-
     @overload
     def __mul__(self: _T, other: Sequence[float]) -> Vector3D:
         ...
 
-    def __mul__(self: _T, other: Union[_T, Quaternion, Sequence[float]]) -> Union[_T, Vector3D]:
-
+    def __mul__(self: _T, other: Union[_T, Sequence[float]]) -> Union[_T, Vector3D]:
         if isinstance(other, Sequence):  # pylint: disable=W1116
-            return self._translation + self._rotation.rotate(other)
+            result: Vector3D = self._translation + rotate_vectors(self._rotation, other)
+            return result
 
-        if isinstance(other, Quaternion):
+        # mypy does not recognize quaternion type, and will infer it as Any.
+        # This typing problem to be resolved.
+        if isinstance(other, quaternion):
             return self._create(self._translation, self._rotation * other)
 
         if isinstance(other, Transform3D):
@@ -101,14 +107,17 @@ class Transform3D(ReprMixin):
 
         return NotImplemented  # type: ignore[unreachable]
 
-    def __rmul__(self: _T, other: Quaternion) -> _T:
-        if isinstance(other, Quaternion):
-            return self._create(other * self._translation, other * self._rotation)
+    def __rmul__(self: _T, other: quaternion) -> _T:
+        if isinstance(other, quaternion):
+            return self._create(
+                Vector3D(*rotate_vectors(other, self._translation)),
+                other * self._rotation,
+            )
 
-        return NotImplemented  # type: ignore[unreachable]
+        return NotImplemented
 
     @classmethod
-    def _create(cls: Type[_T], translation: Vector3D, rotation: Quaternion) -> _T:
+    def _create(cls: Type[_T], translation: Vector3D, rotation: quaternion) -> _T:
         transform: _T = object.__new__(cls)
         transform._translation = translation  # pylint: disable=protected-access
         transform._rotation = rotation  # pylint: disable=protected-access
@@ -116,7 +125,13 @@ class Transform3D(ReprMixin):
 
     def _loads(self, contents: Dict[str, Dict[str, float]]) -> None:
         self._translation = Vector3D.loads(contents["translation"])
-        self._rotation = Quaternion.loads(contents["rotation"])
+        rotation_contents = contents["rotation"]
+        self._rotation = quaternion(
+            rotation_contents["w"],
+            rotation_contents["x"],
+            rotation_contents["y"],
+            rotation_contents["z"],
+        )
 
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Dict[str, float]]) -> _T:
@@ -156,11 +171,11 @@ class Transform3D(ReprMixin):
         return self._translation
 
     @property
-    def rotation(self) -> Quaternion:
+    def rotation(self) -> quaternion:
         """Return the rotation of the 3D transform.
 
         Returns:
-            Rotation in :class:`~tensorbay.geometry.quaternion.Quaternion`.
+            Rotation in numpy quaternion.
 
         """
         return self._rotation
@@ -175,36 +190,39 @@ class Transform3D(ReprMixin):
         """
         return {
             "translation": self._translation.dumps(),
-            "rotation": self._rotation.dumps(),
+            "rotation": {
+                "w": self._rotation.w,
+                "x": self._rotation.x,
+                "y": self._rotation.y,
+                "z": self._rotation.z,
+            },
         }
 
-    def set_translation(self, *args: Union[float, Iterable[float]], **kwargs: float) -> None:
+    def set_translation(self, x: float, y: float, z: float) -> None:
         """Set the translation of the transform.
 
         Arguments:
-            *args: Coordinates of the translation vector.
-            **kwargs: Keyword-only argument to set different dimension for translation vector:
-
+            x: The x coordinate of the translation.
+            y: The y coordinate of the translation.
+            z: The z coordinate of the translation.
                 .. code:: python
 
                     transform.set_translation(x=1, y=2, z=3)
 
         """
-        self._translation = Vector3D(*args, **kwargs)
+        self._translation = Vector3D(x, y, z)
 
-    def set_rotation(
-        self,
-        *args: Union[Quaternion.ArgsType, float],
-        **kwargs: Quaternion.KwargsType,
-    ) -> None:
+    def set_rotation(self, rotation: RotationType) -> None:
         """Set the rotation of the transform.
 
         Arguments:
-            *args: Coordinates of the :class:`Quaternion`.
-            **kwargs: Keyword-only argument to the :class:`Quaternion`.
+            rotation: Rotation in a sequence of [w, x, y, z] or numpy quaternion.
 
         """
-        self._rotation = Quaternion(*args, **kwargs)
+        if isinstance(rotation, quaternion):
+            self._rotation = quaternion(rotation)
+        else:
+            self._rotation = quaternion(*rotation)
 
     def as_matrix(self) -> np.ndarray:
         """Return the transform as a 4x4 transform matrix.
@@ -213,9 +231,9 @@ class Transform3D(ReprMixin):
             A 4x4 numpy array represents the transform matrix.
 
         """
-        matrix = np.eye(4)
+        matrix: np.ndarray = np.eye(4)
         matrix[:3, 3] = self._translation
-        matrix[:3, :3] = self._rotation.as_matrix()
+        matrix[:3, :3] = as_rotation_matrix(self._rotation)
         return matrix
 
     def inverse(self: _T) -> _T:
@@ -226,5 +244,5 @@ class Transform3D(ReprMixin):
 
         """
         rotation = self._rotation.inverse()
-        translation = rotation.rotate(-self._translation)
+        translation = Vector3D(*rotate_vectors(rotation, -self._translation))
         return self._create(translation, rotation)
