@@ -40,7 +40,7 @@ def ImageEmotionAbstract(path: str) -> Dataset:
     segment = dataset.create_segment()
 
     csv_path = os.path.join(root_path, "ABSTRACT_groundTruth.csv")
-    with open(csv_path, "r") as fp:
+    with open(csv_path, "r", encoding="utf-8") as fp:
         reader = csv.DictReader(fp)
         reader.fieldnames = [
             field.strip("'") for field in reader.fieldnames  # type:ignore[union-attr]
