@@ -8,6 +8,8 @@
 
 import os
 
+from quaternion import from_rotation_vector
+
 from ...dataset import Data, Dataset
 from ...label import LabeledBox3D
 from .._utility import glob
@@ -48,7 +50,7 @@ def NeolixOD(path: str) -> Dataset:
         point_cloud_id = os.path.basename(point_cloud_path)[:6]
         label_path = os.path.join(root_path, "labels", f"{point_cloud_id}.txt")
 
-        with open(label_path) as fp:
+        with open(label_path, encoding="utf-8") as fp:
             for label_value_raw in fp:
                 label_value = label_value_raw.rstrip().split()
                 label = LabeledBox3D(
@@ -64,8 +66,7 @@ def NeolixOD(path: str) -> Dataset:
                         float(label_value[12]),
                         float(label_value[13]) + 0.5 * float(label_value[8]),
                     ],
-                    axis=[0, 0, 1],
-                    radians=float(label_value[14]),
+                    rotation=from_rotation_vector((0, 0, float(label_value[14]))),
                 )
                 data.label.box3d.append(label)
 
