@@ -65,7 +65,7 @@ def _load_labels(root_path: str, labels_filename: Optional[str]) -> Dict[str, An
         return {"test": None}
 
     label_path = os.path.join(root_path, labels_filename)
-    with open(label_path, "r") as fp:
+    with open(label_path, "r", encoding="utf-8") as fp:
         loaded_data = json.load(fp)
 
     labels = {}
@@ -104,6 +104,7 @@ def _generate_data(image_path: str, labels: Dict[str, Any]) -> Data:
     for annotation_id in image_annotations_map[image_id]:
         annotation = annotations[annotation_id]
         x_top, y_top, width, height = annotation["bbox"]
+
         attributes = {
             "occluded": annotation["occluded"],
             "difficult": annotation["difficult"],
@@ -112,7 +113,7 @@ def _generate_data(image_path: str, labels: Dict[str, Any]) -> Data:
         }
 
         data.label.box2d.append(
-            LabeledBox2D(
+            LabeledBox2D.from_xywh(
                 x=x_top,
                 y=y_top,
                 width=width,
