@@ -25,7 +25,6 @@ from itertools import count
 from typing import Dict, Iterator, Optional, Sequence, Tuple, Type, TypeVar
 
 import numpy as np
-from typing_extensions import Literal
 
 from ..geometry import Vector2D
 from ..utility import ReprMixin, ReprType, common_loads
@@ -86,6 +85,18 @@ class CameraMatrix(ReprMixin):
 
         raise TypeError(f"Require 'fx', 'fy', 'cx', 'cy' to initialize {self.__class__.__name__}")
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, self.__class__):
+            return False
+
+        return (
+            self.fx == other.fx
+            and self.fy == other.fy
+            and self.cx == other.cx
+            and self.cy == other.cy
+            and self.skew == other.skew
+        )
+
     def _loads(self, contents: Dict[str, float]) -> None:
         self.fx = contents["fx"]
         self.fy = contents["fy"]
@@ -187,11 +198,21 @@ class DistortionCoefficients(ReprMixin):
     def __init__(self, **kwargs: float) -> None:
         self._loads(kwargs)
 
-        if not hasattr(self, "k1") or not hasattr(self, "p1"):
+        if not hasattr(self, "k1") and not hasattr(self, "p1"):
             raise TypeError(
                 f"Require tangential or radial distortion to initialize {self.__class__.__name__}"
             )
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, self.__class__):
+            return False
+
+        for key in self._DISTORTION_KEYS:
+            if tuple(self._list_distortions(key)) != tuple(other._list_distortions(key)):
+                return False
+
+        return True
+
     @staticmethod
     def _distortion_generator(
         distortion_keyword: str, data: Dict[str, float]
@@ -244,7 +265,7 @@ class DistortionCoefficients(ReprMixin):
             for key, value in self._distortion_generator(distortion_key, contents):
                 setattr(self, key, value)
 
-    def _list_distortions(self, distortion_key: Literal["p", "k"]) -> Iterator[float]:
+    def _list_distortions(self, distortion_key: str) -> Iterator[float]:
         """Return the tangential or radial distortion coefficients list.
 
         Arguments:
@@ -283,13 +304,13 @@ class DistortionCoefficients(ReprMixin):
         """
         contents = {}
         for distortion_key in self._DISTORTION_KEYS:
-            distortions = self._list_distortions(distortion_key)  # type: ignore[arg-type]
+            distortions = self._list_distortions(distortion_key)
             for index, value in enumerate(distortions, 1):
                 contents[f"{distortion_key}{index}"] = value
 
         return contents
 
-    def distort(self, point: Sequence[float], *, is_fisheye: bool = False) -> Vector2D:
+    def distort(self, point: Sequence[float], is_fisheye: bool = False) -> Vector2D:
         """Add distortion to a point.
 
         Arguments:
@@ -367,6 +388,15 @@ class CameraIntrinsics(ReprMixin):
                 pass
         self._distortion_coefficients = None
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, self.__class__):
+            return False
+
+        return (
+            self.camera_matrix == other.camera_matrix
+            and self.distortion_coefficients == other.distortion_coefficients
+        )
+
     def _loads(self, contents: Dict[str, Dict[str, float]]) -> None:
         self._camera_matrix = CameraMatrix.loads(contents["cameraMatrix"])
         if "distortionCoefficients" in contents:
@@ -461,5 +491,5 @@ class CameraIntrinsics(ReprMixin):
 
         """
         if self._distortion_coefficients:
-            point = self._distortion_coefficients.distort(point, is_fisheye)  # type: ignore[misc]
+            point = self._distortion_coefficients.distort(point, is_fisheye)
         return self._camera_matrix.project(point)
