@@ -30,7 +30,7 @@ produces strong visual distortion intended to create a wide panoramic or hemisph
 
 from typing import Any, Dict, Iterable, Optional, Sequence, Tuple, Type, TypeVar, Union
 
-from ..geometry import Quaternion, Transform3D
+from ..geometry import Transform3D
 from ..utility import NameMixin, ReprType, TypeEnum, TypeMixin, TypeRegister, common_loads
 from .intrinsics import CameraIntrinsics
 
@@ -136,9 +136,8 @@ class Sensor(NameMixin, TypeMixin[SensorType]):
         self,
         transform: Transform3D.TransformType = None,
         *,
-        translation: Optional[Iterable[float]] = None,
-        rotation: Quaternion.ArgsType = None,
-        **kwargs: Quaternion.KwargsType,
+        translation: Iterable[float] = (0, 0, 0),
+        rotation: Transform3D.RotationType = (1, 0, 0, 0),
     ) -> None:
         """Set the extrinsics of the sensor.
 
@@ -146,48 +145,36 @@ class Sensor(NameMixin, TypeMixin[SensorType]):
             transform: A ``Transform3D`` object representing the extrinsics.
             translation: Translation parameters.
             rotation: Rotation in a sequence of [w, x, y, z] or 3x3 rotation matrix
-                or ``Quaternion``.
-            **kwargs: Other parameters to initialize rotation.
+                or numpy quaternion.
 
         """
-        self.extrinsics = Transform3D(
-            transform, translation=translation, rotation=rotation, **kwargs
-        )
+        self.extrinsics = Transform3D(transform, translation=translation, rotation=rotation)
 
-    def set_translation(
-        self,
-        *args: Union[float, Iterable[float]],
-        **kwargs: float,
-    ) -> None:
+    def set_translation(self, x: float, y: float, z: float) -> None:
         """Set the translation of the sensor.
 
         Arguments:
-            *args: Coordinates of the translation vector.
-            **kwargs: keyword-only argument `x`, `y` and `z` to set different dimension for
-                the translation vector.
+            x: The x coordinate of the translation.
+            y: The y coordinate of the translation.
+            z: The z coordinate of the translation.
 
                     sensor.set_translation(x=1, y=2, z=3)
 
         """
         if not hasattr(self, "extrinsics"):
             self.extrinsics = Transform3D()
-        self.extrinsics.set_translation(*args, **kwargs)
+        self.extrinsics.set_translation(x, y, z)
 
-    def set_rotation(
-        self,
-        *args: Union[Quaternion.ArgsType, float],
-        **kwargs: Quaternion.KwargsType,
-    ) -> None:
+    def set_rotation(self, rotation: Transform3D.RotationType) -> None:
         """Set the rotation of the sensor.
 
         Arguments:
-            *args: Coordinates of the ``Quaternion``.
-            **kwargs: Keyword-only argument to initialize the ``Quaternion``.
+            rotation: Rotation in a sequence of [w, x, y, z] or numpy quaternion.
 
         """
         if not hasattr(self, "extrinsics"):
             self.extrinsics = Transform3D()
-        self.extrinsics.set_rotation(*args, **kwargs)
+        self.extrinsics.set_rotation(rotation)
 
 
 @TypeRegister(SensorType.LIDAR)
@@ -293,7 +280,7 @@ class Camera(Sensor):
 
 
 @TypeRegister(SensorType.FISHEYE_CAMERA)
-class FisheyeCamera(Camera):
+class FisheyeCamera(Camera):  # pylint: disable=too-many-ancestors
     """FisheyeCamera defines the concept of fisheye camera.
 
     Fisheye camera is an ultra wide-angle lens that produces strong visual distortion intended
